/*
  Copyright 2019 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.sample.internal

import android.content.Context
import android.os.Bundle
import androidx.fragment.app.Fragment
import androidx.fragment.app.FragmentManager
import androidx.fragment.app.FragmentStatePagerAdapter
import com.kakao.sdk.partner.model.KakaoPhase
import com.kakao.sdk.partner.sample.PartnerFragment
import com.kakao.sdk.sample.common.OpenFragmentRx

class TabAdapter(context: Context, fm: FragmentManager) :
    FragmentStatePagerAdapter(fm, BEHAVIOR_RESUME_ONLY_CURRENT_FRAGMENT) {
    private val templateIds: Bundle =
        when (KakaoPhase.fromName(
            context.getSharedPreferences(
                "default",
                Context.MODE_PRIVATE
            ).getString("phase", KakaoPhase.PRODUCTION.phaseName) as String
        )) {
            KakaoPhase.DEV -> Bundle().apply {
                putLong("customMemo", 151202)
                putLong("customMessage", 151202)
                putString("channelId", "_xnrxjem")
                putString("calendarEventId", "639964bc7edd5d0c9b722c14")
            }
            KakaoPhase.SANDBOX -> Bundle().apply {
                putLong("customMemo", 682)
                putLong("customMessage", 682)
                putString("channelId", "_KQu")
                putString("calendarEventId", "63917cbbca3adc72adfff94a")
            }
            else -> Bundle().apply {
                putLong("customMemo", 19383)
                putLong("customMessage", 19383)
                putString("channelId", "_ZeUTxl")
                putString("calendarEventId", "63996425afcec577cce94f0b")
            }
        }

    val fragments = listOf(
        HostFragment.newInstance(OpenFragmentRx.newInstance(templateIds), "Open"),
        HostFragment.newInstance(PartnerFragment.newInstance(templateIds), "Partner")
    )

    override fun getItem(position: Int): Fragment = fragments[position]

    override fun getCount(): Int = fragments.size


}